package com.xinelu.manage.mapper.projectresult;

import com.xinelu.manage.domain.projectresult.ProjectResult;
import com.xinelu.manage.dto.projectresult.ProjectResultStatisticDto;
import com.xinelu.manage.vo.projectresult.ProjectResultVo;
import java.util.List;

/**
* @author haown
* @description 针对表【project_result(检测项目结果表)】的数据库操作Mapper
* @createDate 2024-03-06 10:41:36
* @Entity com.xinelu.manage.domain.projectresult.ProjectResult
*/
public interface ProjectResultMapper {

	/**
	 * 查询检测项目结果
	 *
	 * @param id 检测项目结果主键
	 * @return 检测项目结果
	 */
	public ProjectResult selectProjectResultById(Long id);

	/**
	 * 查询检测项目结果列表
	 *
	 * @param projectResult 检测项目结果
	 * @return 检测项目结果集合
	 */
	public List<ProjectResult> selectProjectResultList(ProjectResult projectResult);

	/**
	 * 新增检测项目结果
	 *
	 * @param projectResult 检测项目结果
	 * @return 结果
	 */
	public int insertProjectResult(ProjectResult projectResult);

	/**
	 * 修改检测项目结果
	 *
	 * @param projectResult 检测项目结果
	 * @return 结果
	 */
	public int updateProjectResult(ProjectResult projectResult);

	/**
	 * 删除检测项目结果
	 *
	 * @param id 检测项目结果主键
	 * @return 结果
	 */
	public int deleteProjectResultById(Long id);

	/**
	 * 批量删除检测项目结果
	 *
	 * @param ids 需要删除的数据主键集合
	 * @return 结果
	 */
	public int deleteProjectResultByIds(Long[] ids);

	List<ProjectResultVo> selectList(ProjectResultStatisticDto projectResultStatisticDto);

}
